Welcome to ClientVPS Mirrors

Help for package skewt
Version: 1.0
Date: 2021-12-10
Title: The Skewed Student-t Distribution
Description: Density, distribution function, quantile function and random generation for the skewed t distribution of Fernandez and Steel.
License: GPL-2 | GPL-3 [expanded from: GPL]
NeedsCompilation: no
Packaged: 2021-12-09 23:57:40 UTC; rober
Author: Robert King ORCID iD [aut, cre], Emily Anderson [aut]
Maintainer: Robert King <Robert.King.newcastle@gmail.com>
Repository: CRAN
Date/Publication: 2021-12-10 12:00:02 UTC

The Skewed Student t Distribution

Description

Density, distribution function, quantile function and random generation for the skewed t distribution, as introduced by Fernandez and Steel, with df degrees of freedom.

Usage

dskt(x, df, gamma = 1)
pskt(x, df, gamma = 1)
qskt(p, df, gamma)
rskt(n, df, gamma)

Arguments

x

vector of quantiles.

p

vector of probabilities.

n

number of observations. If length(n) > 1, the length is taken to be the number required.

df

degrees of freedom (> 0, maybe non-integer).

gamma

skewing parameter, \gamma

Details

The Skewed t distribution with df = \nu degrees of freedom has the following density, where f(x) is the density of the t distribution, with = \nu degrees of freedom :

f(x) = \frac{2}{\gamma + \frac{1}{\gamma}} f(\gamma x) \quad for \quad x<0

and

f(x) = \frac{2}{\gamma + \frac{1}{\gamma}} f(\frac{x}{\gamma}) \quad for \quad x \ge 0

Value

dskt gives the density, pskt gives the distribution function, qskt gives the quantile function, and rskt generates random deviates.

References

Fernandez, C. and Steel, M. F. J. (1998). On Bayesian modeling of fat tails and skewness, J. Am. Statist. Assoc. 93, 359–371.

Rohr, P. and Hoeschele, I. (2002). Bayesian QTL mapping using skewed Student-t distributions, Genet. Sel. Evol. 34, 1–21.

See Also

df for the F distribution.

Examples

dskt(0.5,2)
dskt(0.01,2,2)
pskt(1.25,2,2)
pskt(c(0.5,1.25),3)
qskt(c(0,0.025,0.25,0.5,0.75,0.975,1),2,2)
rskt(100,2,2)
plot(function(x)dskt(x,2,2),-3,3,n=301)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.